@@ -1083,7 +1083,7 @@ def main(argv=sys.argv):
                                          args.output_json_path,
                                          args.cv_rules_path,
                                          args.custom_rules_path)
-            generate_html(report, args.output_json_path)
+            # generate_html(report, args.output_json_path)
             generate_html_new(report, args.output_json_path, args.customer_name)
 
         if args.spec_file_path:
@@ -1439,12 +1439,13 @@ def copytree(src, dst, symlinks=False, ignore=None):
 def generate_html_new(report, output_path, customer_name='N/A'):
     curr_dir = os.path.dirname(os.path.abspath(__file__))
     templates_dir = os.path.join(curr_dir, 'sparc-templates-new')
-    output_dir = os.path.join(os.path.dirname(os.path.abspath(output_path)), 'sparc-templates-new')
+    output_dir = os.path.join(os.path.dirname(os.path.abspath(output_path)), 'sparc_report')
     if not os.path.exists(output_dir):
         os.makedirs(output_dir)
 
     #Copy css files to output directory
     copytree(templates_dir, output_dir, symlinks = True)
+    os.remove(os.path.join(output_dir, 'risk-report-template-generic.html'))
 
     html_file = os.path.join(output_dir, 'index.html')
     current_time = datetime.now()
@@ -1493,7 +1494,7 @@ def generate_html_new(report, output_path, customer_name='N/A'):
 def generate_html(report, output_path):
     curr_dir = os.path.dirname(os.path.abspath(__file__))
     templates_dir = os.path.join(curr_dir, 'sparc-templates')
-    output_dir = os.path.join(os.path.dirname(os.path.abspath(output_path)), 'sparc-templates')
+    output_dir = os.path.join(os.path.dirname(os.path.abspath(output_path)), 'sparc_report_old')
     if not os.path.exists(output_dir):
         os.makedirs(output_dir)
 
